@@ -1,6 +1,7 @@
 from asyncio import run
 from threading import Thread
 import time
+import requests
 import websocket
 
 class GraphiteServerConnector:
@@ -15,7 +16,8 @@ class GraphiteServerConnector:
 
     def connect(self):
         def run(*args):
-            self.__ws = websocket.WebSocketApp(self.__server_url + "/client_ws", on_message=self.on_message, on_open=self.on_open, on_close=self.on_close)
+            websocket_url = self.__server_url.replace("http", "ws") + "/client_ws"
+            self.__ws = websocket.WebSocketApp(websocket_url, on_message=self.on_message, on_open=self.on_open, on_close=self.on_close)
             self.__ws.run_forever()
         Thread(target=run).start()
         wait_count = 0
@@ -41,7 +43,16 @@ class GraphiteServerConnector:
         self.__connected = False
 
     def get_client_config(self):
-        self.__ws.send('config')
+        response = requests.get(self.__server_url + "/api/client/config?strategyId=" + self.__strategy_id)
+        if response.status_code != 200:
+            return (False, response.reason)
+        response_json = response.json()
+        return (response_json['success'], response_json['data'])
 
     def upload_state(self, state):
-        self.__ws.send('state ' + state)
+        data = { 'strategyId': self.__strategy_id, 'state': state }
+        response = requests.post(self.__server_url + "/api/client/upload", json=data)
+        if response.status_code != 200:
+            return (False, response.reason)
+        response_json = response.json()
+        return (response_json['success'], response_json['data'])
